.. mom documentation master file, created by
   sphinx-quickstart on Thu Jun 23 23:23:49 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: global.rst.inc

Mom
===

Mother of all our Python projects. Batteries for Python.

Getting the library
---------------------

::

    $ pip install mom

or

::

    $ git clone git://github.com/gorakhargosh/mom.git

    or

    $ git clone http://code.google.com/p/python-mom/

    $ cd mom
    $ python setup.py install

User Guides
===========

.. toctree::
   :maxdepth: 2

   guides/hacking

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/general
   api/codec
   api/security
   api/net
   api/os


Contribute
==========
Found a bug in or want a feature added to |project_name|?
You can fork the official `code repository`_ or file an issue ticket
at the `issue tracker`_. You may also want to refer to :ref:`hacking` for
information about contributing code or documentation to |project_name|.

.. toctree::
   :maxdepth: 2

   guides/hacking

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

